=========
Changelog
=========

Version 0.x
===========

Version 0.3
===========

- Update readme
- Added information about landcover and climate to metadata.

Version 0.2
===========

- Add additional authors.

Version 0.1
===========

- Moved code from pytesmo into this package.
